icalendar.timezone.equivalent\_timezone\_ids module
===================================================

.. automodule:: icalendar.timezone.equivalent_timezone_ids
   :members:
   :show-inheritance:
   :undoc-members:
